@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: bmc-watchdog-argp.c,v 1.20 2009/05/27 20:28:52 chu11 Exp $
+ *  $Id: bmc-watchdog-argp.c,v 1.20.4.2 2009/12/23 21:24:02 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2009 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2010 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2004-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -49,7 +49,7 @@
 
 const char *argp_program_version =
   "bmc-watchdog - " PACKAGE_VERSION "\n"
-  "Copyright (C) 2003-2009 FreeIPMI Core Team\n"
+  "Copyright (C) 2003-2010 FreeIPMI Core Team\n"
   "This program is free software; you may redistribute it under the terms of\n"
   "the GNU General Public License.  This program has absolutely no warranty.";
 
@@ -126,7 +126,7 @@ static struct argp_option cmdline_options[] =
       "Specify time interval before resetting timer.", 57},
     { "help", HELP_KEY, NULL, 0,
       "Output help.", 58},
-    { 0 }
+    { NULL, 0, NULL, 0, NULL, 0}
   };
 
 static error_t cmdline_parse (int key, char *arg, struct argp_state *state);
@@ -487,7 +487,7 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
     case ARGP_KEY_END:
       break;
     default:
-      ret = common_parse_opt (key, arg, state, &(cmd_args->common));
+      ret = common_parse_opt (key, arg, &(cmd_args->common));
       return (ret);
     }
 
