@@ -34,6 +34,7 @@
 #include "ipmi-oem-common.h"
 #include "ipmi-oem-dell.h"
 #include "ipmi-oem-fujitsu.h"
+#include "ipmi-oem-ibm.h"
 #include "ipmi-oem-inventec.h"
 #include "ipmi-oem-sun.h"
 #include "ipmi-oem-supermicro.h"
@@ -89,6 +90,13 @@ struct ipmi_oem_command oem_dell[] =
       IPMI_OEM_COMMAND_FLAGS_DEFAULT,
       ipmi_oem_dell_set_nic_selection
     },
+    {
+      "get-active-lom-status",
+      NULL,
+      0,
+      IPMI_OEM_COMMAND_FLAGS_DEFAULT,
+      ipmi_oem_dell_get_active_lom_status
+    },
     {
       "get-ssh-config",
       NULL,
@@ -212,12 +220,20 @@ struct ipmi_oem_command oem_dell[] =
       IPMI_OEM_COMMAND_FLAGS_OPTIONS_COUNT_VARIABLE,
       ipmi_oem_dell_get_instantaneous_power_consumption_data
     },
+    /* legacy */
     {
       "get-power-headroom-info",
       NULL,
       0,
+      IPMI_OEM_COMMAND_FLAGS_HIDDEN | IPMI_OEM_COMMAND_FLAGS_OPTIONS_COUNT_VARIABLE,
+      ipmi_oem_dell_get_power_head_room
+    },
+    {
+      "get-power-head-room",
+      NULL,
+      0,
       IPMI_OEM_COMMAND_FLAGS_DEFAULT,
-      ipmi_oem_dell_get_power_headroom_info
+      ipmi_oem_dell_get_power_head_room
     },
     {
       "get-power-consumption-statistics",
@@ -422,6 +438,24 @@ struct ipmi_oem_command oem_fujitsu[] =
     },
   };
 
+struct ipmi_oem_command oem_ibm[] =
+  {
+    {
+      "get-led",
+      NULL,
+      0,
+      IPMI_OEM_COMMAND_FLAGS_DEFAULT,
+      ipmi_oem_ibm_get_led
+    },
+    {
+      NULL,
+      NULL,
+      0,
+      IPMI_OEM_COMMAND_FLAGS_DEFAULT,
+      NULL
+    },
+  };
+
 struct ipmi_oem_command oem_inventec[] =
   {
     /* legacy */
@@ -664,6 +698,10 @@ struct ipmi_oem_id oem_cb[] =
       "Fujitsu",
       oem_fujitsu
     },
+    {
+      "IBM",
+      oem_ibm
+    },
     {
       "Inventec",
       oem_inventec
