@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2007-2009 FreeIPMI Core Team
+  Copyright (C) 2007-2010 FreeIPMI Core Team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -226,9 +226,13 @@ _set_alert_policy_table (struct ipmi_pef_config_state_data *state_data,
        *
        * Fujitsu RX 100 S5
        *
+       * Inventec 5441/Dell Xanadu2
+       *
        * All fields have to be applied simultaneously, the motherboard
        * does not appear to like configuration of one field of a time,
-       * always leading to invalid input errors.
+       * always leading to invalid input errors.  This isn't a
+       * compliance issue, but makes it tough to make a portable/good
+       * interface.
        */
       if (ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
           && (ipmi_check_completion_code (obj_cmd_rs,
@@ -249,38 +253,31 @@ _set_alert_policy_table (struct ipmi_pef_config_state_data *state_data,
           if (!section)
             goto cleanup;
           
-          if ((kv = config_find_keyvalue (state_data->pstate,
-                                          section,
+          if ((kv = config_find_keyvalue (section,
                                           "Policy_Type")))
             apt->policy_type = policy_type_number (kv->value_input);
 
-          if ((kv = config_find_keyvalue (state_data->pstate,
-                                          section,
+          if ((kv = config_find_keyvalue (section,
                                           "Policy_Enabled")))
             apt->policy_enabled = same (kv->value_input, "yes");
 
-          if ((kv = config_find_keyvalue (state_data->pstate,
-                                          section,
+          if ((kv = config_find_keyvalue (section,
                                           "Policy_Number")))
             apt->policy_number = atoi (kv->value_input);
 
-          if ((kv = config_find_keyvalue (state_data->pstate,
-                                          section,
+          if ((kv = config_find_keyvalue (section,
                                           "Destination_Selector")))
             apt->destination_selector = atoi (kv->value_input);
           
-          if ((kv = config_find_keyvalue (state_data->pstate,
-                                          section,
+          if ((kv = config_find_keyvalue (section,
                                           "Channel_Number")))
             apt->channel_number = atoi (kv->value_input);
 
-          if ((kv = config_find_keyvalue (state_data->pstate,
-                                          section,
+          if ((kv = config_find_keyvalue (section,
                                           "Alert_String_Set_Selector")))
             apt->alert_string_set_selector = atoi (kv->value_input);
           
-          if ((kv = config_find_keyvalue (state_data->pstate,
-                                          section,
+          if ((kv = config_find_keyvalue (section,
                                           "Event_Specific_Alert_String")))
             apt->event_specific_alert_string = same (kv->value_input, "yes");
 
@@ -765,7 +762,7 @@ ipmi_pef_config_alert_policy_table_section_get (ipmi_pef_config_state_data_t *st
   if (strp)
     free (strp);
   if (section)
-    config_section_destroy (state_data->pstate, section);
+    config_section_destroy (section);
   return (NULL);
 }
 
