@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2008-2009 FreeIPMI Core Team
+  Copyright (C) 2008-2010 FreeIPMI Core Team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@
 
 const char *argp_program_version =
   "ipmi-sensors-config - " PACKAGE_VERSION "\n"
-  "Copyright (C) 2008-2009 FreeIPMI Core Team\n"
+  "Copyright (C) 2008-2010 FreeIPMI Core Team\n"
   "This program is free software; you may redistribute it under the terms of\n"
   "the GNU General Public License.  This program has absolutely no warranty.";
 
@@ -65,7 +65,7 @@ static struct argp_option cmdline_options[] =
     ARGP_COMMON_HOSTRANGED_OPTIONS,
     ARGP_COMMON_OPTIONS_DEBUG,
     CONFIG_ARGP_COMMON_OPTIONS,
-    { 0, }
+    { NULL, 0, NULL, 0, NULL, 0}
   };
 
 static error_t cmdline_parse (int key, char *arg, struct argp_state *state);
@@ -95,13 +95,13 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
     case ARGP_KEY_END:
       break;
     default:
-      ret = config_parse_opt (key, arg, state, &cmd_args->config_args);
+      ret = config_parse_opt (key, arg, &cmd_args->config_args);
       if (ret == ARGP_ERR_UNKNOWN)
-        ret = common_parse_opt (key, arg, state, &(cmd_args->config_args.common));
+        ret = common_parse_opt (key, arg, &(cmd_args->config_args.common));
       if (ret == ARGP_ERR_UNKNOWN)
-        ret = sdr_parse_opt (key, arg, state, &(cmd_args->sdr));
+        ret = sdr_parse_opt (key, arg, &(cmd_args->sdr));
       if (ret == ARGP_ERR_UNKNOWN)
-        ret = hostrange_parse_opt (key, arg, state, &(cmd_args->config_args.hostrange));
+        ret = hostrange_parse_opt (key, arg, &(cmd_args->config_args.hostrange));
       return (ret);
     }
 
