@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2008-2009 FreeIPMI Core Team
+  Copyright (C) 2008-2010 FreeIPMI Core Team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -277,8 +277,7 @@ _ipmi_sensors_config (pstdout_state_t pstate,
       sstr = prog_data->args->config_args.section_strs;
       while (sstr)
         {
-          if (!config_find_section (pstate,
-                                    state_data.sections,
+          if (!config_find_section (state_data.sections,
                                     sstr->section_name))
             {
               pstdout_fprintf (pstate,
@@ -309,8 +308,7 @@ _ipmi_sensors_config (pstdout_state_t pstate,
             struct config_section *s;
             config_err_t this_ret;
 
-            if (!(s = config_find_section (pstate,
-                                           state_data.sections,
+            if (!(s = config_find_section (state_data.sections,
                                            sstr->section_name)))
               {
                 pstdout_fprintf (pstate,
@@ -386,7 +384,7 @@ _ipmi_sensors_config (pstdout_state_t pstate,
   if (file_opened)
     fclose (fp);
   if (state_data.sections)
-    config_sections_destroy (pstate, state_data.sections);
+    config_sections_destroy (state_data.sections);
   return (exit_code);
 }
 
@@ -418,6 +416,12 @@ main (int argc, char **argv)
       goto cleanup;
     }
 
+  if (!hosts_count)
+    {
+      exit_code = EXIT_SUCCESS;
+      goto cleanup;
+    }
+
   /* We don't want caching info to output when are doing ranged output */
   if (hosts_count > 1)
     prog_data.args->sdr.quiet_cache = 1;
