@@ -52,8 +52,7 @@ extern "C" {
 #define IPMI_CMD_OEM_DELL_LCD_INFO                                             0xB5
 /* achu: this one is taken from code, is correct name? */
 #define IPMI_CMD_OEM_DELL_POWER_CAPACITY_STATUS                                0xBA
-/* achu: this one is taken from code, is correct name? */
-#define IPMI_CMD_OEM_DELL_GET_POWER_HEADROOM_INFO                              0xBB
+#define IPMI_CMD_OEM_DELL_GET_POWER_HEAD_ROOM                                  0xBB
 #define IPMI_CMD_OEM_DELL_ROLLBACK_FIRMWARE_VERSION                            0xBE
 #define IPMI_CMD_OEM_DELL_GET_IDRAC_FIRMWARE_VERSION_NUMBER                    0xBF
 #define IPMI_CMD_OEM_DELL_GET_ACTIVE_LOM_STATUS                                0xC1
@@ -103,6 +102,17 @@ extern "C" {
 #define IPMI_CMD_OEM_FUJITSU_GET_REMOTE_STORAGE_CONNECTION_OR_STATUS 0x19
 #define IPMI_CMD_OEM_FUJITSU_SET_VIDEO_DISPLAY_ON_OFF                0x1A
 
+/*******************************************
+ * IBM                                     *
+ *******************************************/
+
+/*
+ * IBM x3455/x3755
+ */
+/* IPMI_NET_FN_OEM_IBM_LED_RQ / IPMI_NET_FN_OEM_IBM_LED_RS */
+/* achu: not official names, named based on use context */
+#define IPMI_CMD_OEM_IBM_GET_LED 0xC0
+
 /******************************************* 
  * Inventec                                *
  *******************************************/
