@@ -50,6 +50,13 @@ extern "C" {
 
 #define IPMI_CALIFORNIA_DIGITAL_PRODUCT_ID_6440 IPMI_INTEL_PRODUCT_ID_SR870BN4
 
+/*
+ * IBM
+ */
+
+#define IPMI_IBM_PRODUCT_ID_X3455 20566
+#define IPMI_IBM_PRODUCT_ID_X3755 14
+
 /* 
  * Inventec
  */
@@ -62,6 +69,12 @@ extern "C" {
 
 #define IPMI_DELL_PRODUCT_ID_XANADU2 IPMI_INVENTEC_PRODUCT_ID_5441
 
+/*
+ * Sun Microsystems
+ */
+
+#define IPMI_SUN_MICROSYSTEMS_PRODUCT_ID_X4140 18177
+
 /*
  * Supermicro
  */
