@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003-2009 FreeIPMI Core Team
+  Copyright (C) 2003-2010 FreeIPMI Core Team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -586,7 +586,10 @@ ipmi_ctx_open_outofband_2_0 (ipmi_ctx_t ctx,
 
   if (ipmi_rmcpplus_init () < 0)
     {
-      API_ERRNO_TO_API_ERRNUM (ctx, errno);
+      if (errno == EPERM)
+        API_SET_ERRNUM (ctx, IPMI_ERR_SYSTEM_ERROR);
+      else
+        API_ERRNO_TO_API_ERRNUM (ctx, errno);
       return (-1);
     }
 
